// 
// このコードは、https://demo.mescius.jp/diodocs/pdf のサンプルの一部として提供されています。
// © MESCIUS inc. All rights reserved.
// 
using System;
using System.IO;
using System.Drawing;
using GrapeCity.Documents.Pdf;
using GrapeCity.Documents.Text;
using GrapeCity.Documents.Pdf.Annotations;
using System.Collections.Generic;
using GrapeCity.Documents.Common;

namespace DsPdfWeb.Demos
{
    // このサンプルでは、PDF ドキュメント内のフレーズをすべて検索し、検索結果すべてを
    // テキストマークアップ注釈の波状下線を使用して強調表示する方法を紹介しています。
    // 単語が改行で区切られていても、フレーズ「javascript framework」がすべて検索できるように、
    // 検索文字列に正規表現を使用しています。
    public class FindAndSquiggly
    {
        public int CreatePDF(Stream stream)
        {
            // PDF を読み込みます。
            var doc = new GcPdfDocument();
            using var fs = File.OpenRead(Path.Combine("Resources", "PDFs", "CompleteJavaScriptBook.pdf"));
            doc.Load(fs);

            // 改行で区切られても検索できるように、正規表現を使用して
            // フレーズ「javascript framework」をすべて検索します。
            var ft = new FindTextParams("javascript\\s+framework", wholeWord: false, matchCase: false, regex: true);
            var found = doc.FindText(ft, null);

            // テキストマークアップ注釈を追加し、検索結果すべてに波状下線を引きます。
            foreach (var f in found)
            {
                var markup = new TextMarkupAnnotation()
                {
                    Page = doc.Pages[f.PageIndex],
                    MarkupType = TextMarkupType.Squiggly,
                    Color = Color.Magenta
                };
                List<Quadrilateral> area = new List<Quadrilateral>();
                foreach (var b in f.Bounds)
                    area.Add(b);
                markup.Area = area;
            }

            // PDF ドキュメントを保存します。
            doc.Save(stream);
            return doc.Pages.Count;
        }
    }
}
